Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(412)

Unified Diff: content/browser/frame_host/render_frame_host_delegate.h

Issue 2921823002: Rationalize WakeLock naming conventions (Closed)
Patch Set: rebase Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/frame_host/render_frame_host_delegate.h
diff --git a/content/browser/frame_host/render_frame_host_delegate.h b/content/browser/frame_host/render_frame_host_delegate.h
index 0f5ae3a272b8540bfaad4edbe1bbf820216c69c3..60e5680812f93201584a013dd5f02fc80732bde0 100644
--- a/content/browser/frame_host/render_frame_host_delegate.h
+++ b/content/browser/frame_host/render_frame_host_delegate.h
@@ -18,7 +18,7 @@
#include "content/public/browser/site_instance.h"
#include "content/public/common/javascript_dialog_type.h"
#include "content/public/common/media_stream_request.h"
-#include "device/wake_lock/public/interfaces/wake_lock_service.mojom.h"
+#include "device/wake_lock/public/interfaces/wake_lock.mojom.h"
#include "mojo/public/cpp/bindings/scoped_interface_endpoint_handle.h"
#include "net/http/http_response_headers.h"
#include "ui/base/window_open_disposition.h"
@@ -192,8 +192,8 @@ class CONTENT_EXPORT RenderFrameHostDelegate {
// Gets the GeolocationServiceContext associated with this delegate.
virtual device::GeolocationServiceContext* GetGeolocationServiceContext();
- // Gets the WakeLockService that serves wake lock requests from the renderer.
- virtual device::mojom::WakeLockService* GetRendererWakeLock();
+ // Gets the WakeLock that serves wake lock requests from the renderer.
+ virtual device::mojom::WakeLock* GetRendererWakeLock();
#if defined(OS_ANDROID)
// Gets an NFC implementation within the context of this delegate.
« no previous file with comments | « content/browser/download/download_request_core.h ('k') | content/browser/frame_host/render_frame_host_delegate.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698